@@ -20,9 +20,8 @@ from motulator.model.converter import (
 from motulator.model.im import (
     InductionMotor,
     InductionMotorSaturated,
-    SaturableStatorInductance,
     InductionMotorInvGamma)
-from motulator.model.sm import SynchronousMotor
+from motulator.model.sm import SynchronousMotor, SynchronousMotorSaturated
 from motulator.model.im_drive import (
     InductionMotorDrive,
     InductionMotorDriveDiode)
@@ -38,6 +37,9 @@ from motulator.control.im_vector import (
 from motulator.control.sm_vector import (
     SynchronousMotorVectorCtrl,
     SynchronousMotorVectorCtrlPars)
+from motulator.control.sm_flux_vector import (
+    SynchronousMotorFluxVectorCtrl,
+    SynchronousMotorFluxVectorCtrlPars)
 
 # Import other useful stuff
 from motulator.helpers import (
