@@ -1,4 +1,4 @@
-# pylint: disable=C0103
+# pylint: disable=invalid-name
 """
 Continuous-time models for induction motor drives.
 
@@ -8,17 +8,15 @@ induction motor.
 
 """
 from __future__ import annotations
-from dataclasses import dataclass, field
 import numpy as np
 
 from motulator.helpers import abc2complex, Bunch
-from motulator.model.im import InductionMotor, InductionMotorSaturated
+from motulator.model.im import InductionMotor
 from motulator.model.mech import Mechanics
 from motulator.model.converter import Inverter, FrequencyConverter
 
 
 # %%
-@dataclass
 class InductionMotorDrive:
     """
     Continuous-time model for an induction motor drive.
@@ -37,16 +35,16 @@ class InductionMotorDrive:
         Inverter model.
 
     """
-    motor: InductionMotor | InductionMotorSaturated = InductionMotor()
-    mech: Mechanics = Mechanics()
-    conv: Inverter = Inverter()
-    # Stores the solution data
-    data: Bunch = field(repr=False, default_factory=Bunch)
-    # Initial time
-    t0: float = field(repr=False, default=0)
 
-    def __post_init__(self):
+    def __init__(self,
+                 motor=InductionMotor(), mech=Mechanics(), conv=Inverter()):
+
+        self.motor = motor
+        self.mech = mech
+        self.conv = conv
+        self.t0 = 0  # Initial time
         # Store the solution in these lists
+        self.data = Bunch()  # Stores the solution data
         self.data.t, self.data.q = [], []
         self.data.psi_ss, self.data.psi_rs = [], []
         self.data.theta_M, self.data.w_M = [], []
@@ -138,6 +136,7 @@ class InductionMotorDrive:
         # From lists to the ndarray
         for key in self.data:
             self.data[key] = np.asarray(self.data[key])
+
         # Some useful variables
         self.data.i_ss, _ = self.motor.currents(self.data.psi_ss,
                                                 self.data.psi_rs)
@@ -149,6 +148,7 @@ class InductionMotorDrive:
                            + self.mech.B*self.data.w_M)
         self.data.u_ss = self.conv.ac_voltage(self.data.q,
                                               self.conv.u_dc0)
+
         # Compute the inverse-Γ rotor flux
         try:
             # Saturable stator inductance
@@ -161,7 +161,6 @@ class InductionMotorDrive:
 
 
 # %%
-@dataclass
 class InductionMotorDriveDiode(InductionMotorDrive):
     """
     Induction motor drive equipped with a diode bridge.
@@ -172,52 +171,60 @@ class InductionMotorDriveDiode(InductionMotorDrive):
 
     Parameters
     ----------
-
+    motor : InductionMotor | InductionMotorSaturated
+        Induction motor model.
+    mech : Mechanics
+        Mechanics model.
     conv : FrequencyConverter
         Frequency converter model.
 
     """
-    conv: FrequencyConverter = None
 
-    def __post_init__(self):
-        # Extends the base class, store the solution in these lists
-        self.data.t, self.data.q = [], []
-        self.data.psi_ss, self.data.psi_rs = [], []
-        self.data.theta_M, self.data.w_M = [], []
+    def __init__(self, motor=InductionMotor(), mech=Mechanics(),
+                 conv=FrequencyConverter()):
+
+        # Extend the base class
+        super().__init__(motor=motor, mech=mech)
+        self.conv = conv
         self.data.u_dc, self.data.i_L = [], []
 
     def get_initial_values(self):
-        # Extends the base class
+
+        # Extend the base class
         x0 = super().get_initial_values() + [self.conv.u_dc0, self.conv.i_L0]
         return x0
 
     def set_initial_values(self, t0, x0):
-        # Extends the base class
+
+        # Extend the base class
         super().set_initial_values(t0, x0[0:4])
         self.conv.u_dc0 = x0[4].real
         self.conv.i_L0 = x0[5].real
 
     def f(self, t, x):
-        # Overrides the base class, unpack the states for better readability
+
+        # Override the base class, unpack the states for better readability
         psi_ss, psi_rs, w_M, _, u_dc, i_L = x
         # Interconnections: outputs for computing the state derivatives
         i_ss, _ = self.motor.currents(psi_ss, psi_rs)
         u_ss = self.conv.ac_voltage(self.conv.q, u_dc)
         i_dc = self.conv.dc_current(self.conv.q, i_ss)
         tau_M = self.motor.torque(psi_ss, i_ss)
-        # Returns the list of state derivatives
+        # Return the list of state derivatives
         return (self.motor.f(psi_ss, psi_rs, u_ss, w_M) +
                 self.mech.f(t, w_M, tau_M) +
                 self.conv.f(t, u_dc, i_L, i_dc))
 
     def save(self, sol):
-        # Extends the base class
+
+        # Extend the base class
         super().save(sol)
         self.data.u_dc.extend(sol.y[4].real)
         self.data.i_L.extend(sol.y[5].real)
 
     def post_process(self):
-        # Extends the base class
+
+        # Extend the base class
         super().post_process()
         # From lists to the ndarray
         self.data.u_dc = np.asarray(self.data.u_dc)
